/*  igord.c --- broadcaster daemon

 Copyright (C) 2009 by Walter C. Pelissero

 Author: Walter C. Pelissero <walter@pelissero.de>
 Project: igorplug

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2, or (at
your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; see the file COPYING.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.*/

#include <string.h>
#include <stdlib.h>
#include <errno.h>
#include <unistd.h>
#include <stdio.h>

#include "igorplug.h"
#include "util.h"

static int
main_loop2 (int fd, unsigned tolerance)
{
  unsigned char *buf = igorplug_alloc_buffer();

  while (1)
    {
      if (igorplug_read_buffer2(fd, buf, tolerance) < 0)
	{
	  fprintf(stderr, "igorplug_read_buffer2 failed (errno=%d)\n", errno);
	  exit(2);
	}
      print_packet(buf, stdout);
    }
}

static void
usage (const char *my_name)
{
  printf("usage: %s [-d] /dev/ugenX\nEcho IR packets to standard output.\n", my_name);
  exit(1);
}

int
main (int argc, char *argv[])
{
  int fd;
  unsigned tolerance = DEFAULT_TOLERANCE;
  char c;

  while ((c = getopt(argc, argv, "d")) != -1)
    {
      switch (c)
	{
	case 'd':
	  debug = true;
	  break;
	case '?':
	default:
	  usage(argv[0]);
	}
    }
  if (argc - optind < 1)
    usage(argv[0]);
  dprint("opening %s\n", argv[optind]);
  fd = igorplug_open_device(argv[optind]);
  main_loop2(fd, tolerance);
  /* should never get here */
  return 2;
}
